@@ -203,6 +203,23 @@ class Module(RedisMixin, LoggingMixin, RollbarMixin):
         worker = API()
         worker.post(path="/v1/data/corva", data=output)
 
+    def build_empty_output(self, wits: dict) -> dict:
+        """
+        Building an empty output result.
+        :param wits: one wits record
+        :return:
+        """
+        output = {
+            'timestamp': int(wits.get('timestamp')),
+            'company_id': int(wits.get('company_id')),
+            'asset_id': int(wits.get('asset_id')),
+            'provider': str(wits.get('provider', 'corva')),
+            'version': 1,
+            'collection': self.collection,
+            'data': {}
+        }
+        return output
+
     @staticmethod
     def format_output(output):
         output = json.dumps(output)
