@@ -92,15 +92,8 @@ class ActivityModule(Module):
             return []
 
         asset_id = self.global_state['asset_id']
-        main_structure = {
-            'timestamp': int(first_wits.get('timestamp')),
-            'company_id': int(first_wits.get('company_id')),
-            'asset_id': asset_id,
-            'provider': 'corva',
-            'version': 1,
-            'collection': self.collection,
-            'data': {}
-        }
+        main_structure = self.build_empty_output(first_wits)
+
         warning = None
         last_document = None
 
