@@ -1,9 +1,22 @@
+from typing import Union
+
 import numpy as np
 
 from worker.data.api import API
 
 
-def gather_wits_for_period(asset_id, start, end, limit=1800):
+def gather_wits_for_period(asset_id: int, start: int, end: int, limit: int = 1800) -> list:
+    """
+    Get the wits data from API for an asset over an interval
+    :param asset_id: asset id
+    :param start: start timestamp
+    :param end: end timestamp
+    :param limit: count of the data
+    :return: a list of wits data
+    """
+    if start >= end:
+        return []
+
     query = '{timestamp#gte#%s}AND{timestamp#lte#%s}' % (start, end)
     worker = API()
     wits_dataset = worker.get(
@@ -11,41 +24,49 @@ def gather_wits_for_period(asset_id, start, end, limit=1800):
     ).data
 
     if not wits_dataset:
-        return None
+        return []
 
     return wits_dataset
 
 
-def get_one_wits_record(asset_id, timestamp_sort=-1):
+def get_one_wits_record(asset_id: int, timestamp_sort: int = -1) -> dict:
+    """
+    Get the first or last wits record of a given asset
+    :param asset_id:
+    :param timestamp_sort:
+    :return:
+    """
     api_worker = API()
     data = api_worker.get(path='/v1/data/corva/', collection='wits', asset_id=asset_id,
                           sort="{timestamp:%s}" % timestamp_sort, limit=1).data
     if not data:
-        return None
+        return {}
 
-    timestamp = data[0].get('timestamp', 0)
-    return timestamp
+    return data[0]
 
 
-def get_config_by_id(config_collection, _id):
+def get_config_by_id(config_collection: str, _id: str):
     worker = API()
     config = worker.get(path="/v1/data/corva/%s/%s" % (config_collection, _id)).data
     return config
 
 
-def delete_collection_data_of_asset_id(asset_id, collection):
+def delete_collection_data_of_asset_id(asset_id: int, collections: Union[str, list]):
     """
     Delete all the data of a collection for an asset id.
     :param asset_id:
-    :param collection:
+    :param collections: a collection or a list of collections
     :return:
     """
     worker = API()
 
-    path = "/v1/data/corva/%s" % collection
-    query = "{asset_id#eq#%s}" % asset_id
-    worker.delete(path=path, query=query)
-    print(f"Deleted {collection} for asset_id {asset_id}.")
+    if isinstance(collections, str):
+        collections = [collections]
+
+    for collection in collections:
+        path = "/v1/data/corva/%s" % collection
+        query = "{asset_id#eq#%s}" % asset_id
+        worker.delete(path=path, query=query)
 
 
 def is_number(data):
@@ -69,10 +90,14 @@ def is_number(data):
 def is_finite(data):
     """
     Check if the given data is a finite number
-    :param data: Input can be string, number or nan
+    Note that the string representation of a number is not finite
+    :param data:
     :return: True or False
     """
-    return is_number(data) and np.isfinite(data)
+    try:
+        return is_number(data) and np.isfinite(data)
+    except (TypeError, ValueError):
+        return False
 
 
 def to_number(data):
